# super fancy new All static microraptor plotter
require(ggplot2)

# FIRST SOME DATA HANDLING
# Load all Microraptor static data
#D <- read.table('Microraptor gui static forces.txt',header=TRUE)
D <- read.table('Microraptor gui paper feathers.txt',header=TRUE)

M <- read.table('featherspaper.txt',header=TRUE) # Load model data

# Select which models to plot or do all
# for today's exercise, just work with a few runs
D <- subset(D,((D$aoa<45)&(D$aoa>-20)))


# This line strips out the ones we want to plot
# and adds columns the model data such as 
# basemodel and with/without leg feathers
TheData <- merge(D,M)
TheData <- droplevels(TheData) # Drop unused levels

# Compute some extra columns
# Nondimensional coefficients, referenced to sprawled planform
TheData$Re <- TheData$v*TheData$model.svl/TheData$nu
TheData$CLift <- TheData$lift/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CPitch <- TheData$pitch/(1/2*TheData$rho*TheData$v**2*TheData$model.area*TheData$ref.svl)



model1 = aov(CLift~aoa*factor(wingtype),data=TheData)
model1b = aov(CLift~factor(wingtype)*aoa,data=TheData)
model2 = aov(CLift~aoa+factor(wingtype),data=TheData)
model3 = aov(CLift~factor(wingtype),data=TheData)
model4 = aov(CLift~aoa,data=TheData)

# AOA effect significant, p<2e-16
# wing type and interaction terms not significant p>0.1168

foo = lm(CLift~aoa,data=TheData)







# now do some nice plots
fig4 <- ggplot(TheData, aes(aoa,CLift,colour=basemodel,shape=wingtype))+xlim(-15,40)+xlab('angle of attack, deg')+ylab('lift coefficient')+geom_point()+geom_abline(intercept=0.27165,slope=0.02383,color="#4DAF4A")

pdf(file="feathercheck.pdf",width=3,height=2)
print(fig4+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+scale_shape_manual(values=c('feathers'=16,'paper'=21))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()


