# super fancy new All static microraptor plotter
require(ggplot2)

# FIRST SOME DATA HANDLING
# Load all Microraptor static data
D <- read.table('Microraptor gui static forces.txt',header=TRUE)
M <- read.table('control effectiveness.txt',header=TRUE) # Load model data

# Select which models to plot or do all
# for today's exercise, just work with a few runs
#D <- subset(D,run=="20100914A")

# This line strips out the ones we want to plot
# and adds columns the model data such as 
# basemodel and with/without leg feathers
TheData <- merge(D,M)
TheData <- droplevels(TheData) # Drop unused levels

# Compute some extra columns
# Nondimensional coefficients, referenced to sprawled planform
TheData$Re <- TheData$v*TheData$model.svl/TheData$nu
TheData$CLift <- TheData$lift/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CDrag <- TheData$drag/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CSide <- TheData$side/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CPitch <- TheData$pitch/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CRoll <- TheData$roll/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CYaw <- TheData$yaw/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)

# Scale up to full scale forces at 12 m/s (arbitrary)
fs.svl <- 0.306 # IVPP specimen
fs.area <- 0.211 # IVPP specimen
fs.m <- 1 # ??? 
g <- 9.81 # m/s^2
nu <- 15e-6 
fs.U <- 12 # iterate
fs.Re <- fs.U*fs.svl/nu
TheData$LIFT <- TheData$CLift*1/2*TheData$rho*fs.U**2*fs.area
TheData$DRAG <- TheData$CDrag*1/2*TheData$rho*fs.U**2*fs.area
TheData$SIDE <- TheData$CSide*1/2*TheData$rho*fs.U**2*fs.area
TheData$PITCH <- TheData$CPitch*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$ROLL <- TheData$CRoll*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$YAW <- TheData$CYaw*1/2*TheData$rho*fs.U**2*fs.area*fs.svl

# Some simple metrics
TheData$ClCd <- TheData$CLift/TheData$CDrag
TheData$glideangle <- atan2(TheData$CDrag,TheData$CLift)*180/pi
TheData$Umin <- sqrt((fs.m*g*cos(TheData$glideangle))/(1/2*TheData$rho*TheData$CLift*fs.area))
TheData$Uterm <- sqrt((fs.m*g)/(1/2*TheData$rho*TheData$CDrag*fs.area))
TheData$Upropelled <- sqrt((fs.m*g)/(1/2*TheData$rho*TheData$CLift*fs.area))






# now do some nice plots


# coefficients
fig1 <- ggplot(TheData, aes(aoa,CLift,colour=basemodel,shape=factor(sweepangle)))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('lift coefficient')+geom_point(alpha=I(1/5))+geom_smooth()
pdf(file="Clvsaoa.pdf",width=3,height=2)
print(fig1+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+scale_shape_manual(values=c(6,25,22,24,2))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig2 <- ggplot(TheData, aes(aoa,CDrag,colour=basemodel,shape=factor(sweepangle)))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('drag coefficient')+geom_point(alpha=I(1/5))+geom_smooth()
pdf(file="Cdvsaoa.pdf",width=3,height=2)
print(fig2+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+scale_shape_manual(values=c(6,25,22,24,2))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig3 <- ggplot(TheData, aes(aoa,CPitch,colour=basemodel,shape=factor(sweepangle)))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('pitching moment coefficient')+geom_point(alpha=I(1/5))+geom_smooth()
pdf(file="Cmvsaoa.pdf",width=3,height=2)
print(fig3+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+scale_shape_manual(values=c(6,25,22,24,2))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()




# find slopes
# sort the data
sortedData <- TheData[with(TheData,order(run,aoa)),]
mysloper <- function(df){with(df,data.frame(aoa=aoa[-1],dCMda=diff(CPitch)/(diff(aoa)*pi/180)))}
DCMDA <- ddply(sortedData,.(run),mysloper)
StabData <- merge(TheData,DCMDA)

fig8f <- ggplot(StabData, aes(aoa,dCMda,colour=basemodel,shape=factor(sweepangle)))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('pitching stability coefficient')+geom_point(alpha=I(1/5))+geom_smooth()
pdf(file="pitchstab.pdf",width=3,height=2)
print(fig8f+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+scale_shape_manual(values=c(6,25,22,24,2))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()
# Not really interesting... 





# Save excel spreadsheet 
write.table(StabData,"basicpitchaerodynamics.xls",sep="\t",na="",row.names=F)
