# super fancy new All static microraptor plotter
require(ggplot2)
require(plyr)
#require(pgirmess)

# FIRST SOME DATA HANDLING
# Load all Microraptor static data
D <- read.table('Microraptor gui static forces.txt',header=TRUE)
M <- read.table('basic stability.txt',header=TRUE) # Load model data

# Select which models to plot or do all
# for today's exercise, just work with a few runs
#D <- subset(D,run=="20100914A")

# This line strips out the ones we want to plot
# and adds columns the model data such as 
# basemodel and with/without leg feathers
TheData <- merge(D,M)
TheData <- droplevels(TheData) # Drop unused levels

# Compute some extra columns
# Nondimensional coefficients, referenced to sprawled planform
TheData$Re <- TheData$v*TheData$model.svl/TheData$nu
TheData$CLift <- TheData$lift/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CDrag <- TheData$drag/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CSide <- TheData$side/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CPitch <- TheData$pitch/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CRoll <- TheData$roll/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CYaw <- TheData$yaw/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)

# Scale up to full scale forces at 12 m/s (arbitrary)
fs.svl <- 0.306 # IVPP specimen
fs.area <- 0.211 # IVPP specimen
fs.m <- 1 # ??? 
g <- 9.81 # m/s^2
nu <- 15e-6 
fs.U <- 12 # iterate
fs.Re <- fs.U*fs.svl/nu
TheData$LIFT <- TheData$CLift*1/2*TheData$rho*fs.U**2*fs.area
TheData$DRAG <- TheData$CDrag*1/2*TheData$rho*fs.U**2*fs.area
TheData$SIDE <- TheData$CSide*1/2*TheData$rho*fs.U**2*fs.area
TheData$PITCH <- TheData$CPitch*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$ROLL <- TheData$CRoll*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$YAW <- TheData$CYaw*1/2*TheData$rho*fs.U**2*fs.area*fs.svl

# Some simple metrics
TheData$ClCd <- TheData$CLift/TheData$CDrag
TheData$glideangle <- atan2(TheData$CDrag,TheData$CLift)*180/pi
TheData$Umin <- sqrt((fs.m*g*cos(TheData$glideangle))/(1/2*TheData$rho*TheData$CLift*fs.area))
TheData$Uterm <- sqrt((fs.m*g)/(1/2*TheData$rho*TheData$CDrag*fs.area))
TheData$Upropelled <- sqrt((fs.m*g)/(1/2*TheData$rho*TheData$CLift*fs.area))

TheData$MI1 = TheData$CLift/(fs.m*g/fs.area)
TheData$MI2 = TheData$LIFT/(fs.m*g)*cos(60*pi/180)
TheData$MIc = TheData$SIDE/(fs.m*g)*sin(60*pi/180)


TheData90 <- subset(TheData,aoa==90)
fig1 <- ggplot(TheData90, aes(basemodel,DRAG,fill=basemodel))+ylim(0,25)+xlab('Posture')+ylab('D90 full scale drag, N')+geom_boxplot()+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="D90vsposture.pdf",width=3,height=2)
print(fig1+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

model1 = aov(DRAG~basemodel,data=TheData90)
summary(model1)
TukeyHSD(model1)

#require(pgirmess)
#model1b = kruskal.test(DRAG~basemodel,data=TheData90)
#summary(model1b)
#kruskalmc(TheData90$DRAG,TheData90$basemodel)







UMIN <- ddply(TheData,.(run,basemodel),function(df){min(df$Umin,na.rm=TRUE)})
fig2 <- ggplot(UMIN, aes(basemodel,V1,fill=basemodel))+ylim(0,30)+xlab('Posture')+ylab('glide initiation speed, m/s')+geom_boxplot()+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="Uminvsposture.pdf",width=3,height=2)
print(fig2+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

#model2b = kruskal.test(V1~basemodel,data=UMIN)
#summary(model2b)
#kruskalmc(UMIN$V1,UMIN$basemodel)






CLCD <- ddply(TheData,.(run,basemodel),function(df){max(df$ClCd,na.rm=TRUE)})
fig3 <- ggplot(CLCD, aes(basemodel,V1,fill=basemodel))+ylim(0,4)+xlab('Posture')+ylab('max lift to drag ratio')+geom_boxplot()+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="ClCdvsposture.pdf",width=3,height=2)
print(fig3+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

#model3b = kruskal.test(V1~basemodel,data=CLCD)
#summary(model3b)
#kruskalmc(CLCD$V1,CLCD$basemodel)

#XXX <- subset(CLCD,V1<4)
#tapply(XXX$V1,XXX$basemodel,quantile)




MI1 <- ddply(TheData,.(run,basemodel),function(df){max(df$MI1,na.rm=TRUE)})
fig4 <- ggplot(MI1, aes(basemodel,V1,fill=basemodel))+ylim(0,0.025)+xlab('Posture')+ylab('MI1')+geom_boxplot()+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="MI1vsposture.pdf",width=3,height=2)
print(fig4+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

#model4b = kruskal.test(V1~basemodel,data=MI1)
#summary(model4b)
#kruskalmc(MI1$V1,MI1$basemodel)
#XXX <- subset(MI1,V1<4)
#tapply(XXX$V1,XXX$basemodel,quantile)

MI2 <- ddply(TheData,.(run,basemodel),function(df){max(df$MI2,na.rm=TRUE)})
fig5 <- ggplot(MI2, aes(basemodel,V1,fill=basemodel))+ylim(0,1)+xlab('Posture')+ylab('MI2')+geom_boxplot()+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="MI2vsposture.pdf",width=3,height=2)
print(fig5+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

#model5b = kruskal.test(V1~basemodel,data=MI2)
#summary(model5b)
#kruskalmc(MI2$V1,MI2$basemodel)
#XXX <- subset(MI2,V1<4)
#tapply(XXX$V1,XXX$basemodel,quantile)

MIc <- ddply(TheData,.(run,basemodel),function(df){max(df$MIc,na.rm=TRUE)})
fig6 <- ggplot(MIc, aes(basemodel,V1,fill=basemodel))+ylim(0,0.25)+xlab('Posture')+ylab('MI crabbed')+geom_boxplot()+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="MIcvsposture.pdf",width=3,height=2)
print(fig6+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

#model6b = kruskal.test(V1~basemodel,data=MI3)
#summary(model6b)
#kruskalmc(MI3$V1,MI3$basemodel)
#XXX <- subset(MI3,V1<4)
#tapply(XXX$V1,XXX$basemodel,quantile)

