# super fancy new All static microraptor plotter
require(ggplot2)

# FIRST SOME DATA HANDLING
# Load all Microraptor static data
D <- read.table('Microraptor gui static forces.txt',header=TRUE)
M <- read.table('ae stability.txt',header=TRUE) # Load model data

# Select which models to plot or do all
# for today's exercise, just work with a few runs
#D <- subset(D,run=="20100914A")

# This line strips out the ones we want to plot
# and adds columns the model data such as 
# basemodel and with/without leg feathers
TheData <- merge(D,M)
TheData <- droplevels(TheData) # Drop unused levels

# Compute some extra columns
# Nondimensional coefficients, referenced to sprawled planform
TheData$Re <- TheData$v*TheData$model.svl/TheData$nu
TheData$CLift <- TheData$lift/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CDrag <- TheData$drag/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CSide <- TheData$side/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CPitch <- TheData$pitch/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CRoll <- TheData$roll/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CYaw <- TheData$yaw/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)

# Scale up to full scale forces at 12 m/s (arbitrary)
fs.svl <- 0.306 # IVPP specimen
fs.area <- 0.211 # IVPP specimen
fs.m <- 1 # ??? 
g <- 9.81 # m/s^2
nu <- 15e-6 
fs.U <- 12 # iterate
fs.Re <- fs.U*fs.svl/nu
TheData$LIFT <- TheData$CLift*1/2*TheData$rho*fs.U**2*fs.area
TheData$DRAG <- TheData$CDrag*1/2*TheData$rho*fs.U**2*fs.area
TheData$SIDE <- TheData$CSide*1/2*TheData$rho*fs.U**2*fs.area
TheData$PITCH <- TheData$CPitch*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$ROLL <- TheData$CRoll*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$YAW <- TheData$CYaw*1/2*TheData$rho*fs.U**2*fs.area*fs.svl

# Some simple metrics
TheData$ClCd <- TheData$CLift/TheData$CDrag
TheData$glideangle <- atan2(TheData$CDrag,TheData$CLift)*180/pi
TheData$Umin <- sqrt((fs.m*g*cos(TheData$glideangle))/(1/2*TheData$rho*TheData$CLift*fs.area))
TheData$Uterm <- sqrt((fs.m*g)/(1/2*TheData$rho*TheData$CDrag*fs.area))
TheData$Upropelled <- sqrt((fs.m*g)/(1/2*TheData$rho*TheData$CLift*fs.area))



TheData90 <- subset(TheData,aoa==90)
fig1 <- ggplot(TheData90, aes(basemodel,DRAG,color=leg.feathers,fill=basemodel))+ylim(0,25)+xlab('Posture')+ylab('D90 full scale drag, N')+geom_boxplot()+scale_colour_manual(values=c("gray20","gray80"))+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="D90vsposturefeathers.pdf",width=3,height=2)
print(fig1+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

model1 = aov(DRAG~basemodel*as.factor(leg.feathers),data=TheData90)
summary(model1)
TukeyHSD(model1)








UMIN <- ddply(TheData,.(run,basemodel,leg.feathers),function(df){min(df$Umin,na.rm=TRUE)})
fig2 <- ggplot(UMIN, aes(basemodel,V1,color=leg.feathers,fill=basemodel))+ylim(0,30)+xlab('Posture')+ylab('glide initiation speed, m/s')+geom_boxplot()+scale_colour_manual(values=c("gray20","gray80"))+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="Uminvsposturefeathers.pdf",width=3,height=2)
print(fig2+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

model2 = aov(V1~basemodel*as.factor(leg.feathers),data=UMIN)
summary(model2)
TukeyHSD(model2)







CLCD <- ddply(TheData,.(run,basemodel,leg.feathers),function(df){max(df$ClCd,na.rm=TRUE)})
fig3 <- ggplot(CLCD, aes(basemodel,V1,color=leg.feathers,fill=basemodel))+ylim(0,6)+xlab('Posture')+ylab('max lift to drag ratio')+geom_boxplot()+scale_colour_manual(values=c("gray20","gray80"))+scale_fill_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))
pdf(file="ClCdvsposturefeathers.pdf",width=3,height=2)
print(fig3+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

model3 = aov(V1~basemodel*as.factor(leg.feathers),data=CLCD)
summary(model3)
TukeyHSD(model3)


