# super fancy new All static microraptor plotter
require(ggplot2)

# FIRST SOME DATA HANDLING
# Load all Microraptor static data
D <- read.table('Microraptor gui static forces.txt',header=TRUE)
M <- read.table('basic stability.txt',header=TRUE) # Load model data

# Select which models to plot or do all
# for today's exercise, just work with a few runs
#D <- subset(D,run=="20100914A")

# This line strips out the ones we want to plot
# and adds columns the model data such as 
# basemodel and with/without leg feathers
TheData <- merge(D,M)
TheData <- droplevels(TheData) # Drop unused levels

# Compute some extra columns
# Nondimensional coefficients, referenced to sprawled planform
TheData$Re <- TheData$v*TheData$model.svl/TheData$nu
TheData$CLift <- TheData$lift/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CDrag <- TheData$drag/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CSide <- TheData$side/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CPitch <- TheData$pitch/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CRoll <- TheData$roll/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CYaw <- TheData$yaw/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)

# Scale up to full scale forces at 12 m/s (arbitrary)
fs.svl <- 0.306 # IVPP specimen
fs.area <- 0.211 # IVPP specimen
fs.m <- 1 # ??? 
g <- 9.81 # m/s^2
nu <- 15e-6 
fs.U <- 12 # iterate
fs.Re <- fs.U*fs.svl/nu
TheData$LIFT <- TheData$CLift*1/2*TheData$rho*fs.U**2*fs.area
TheData$DRAG <- TheData$CDrag*1/2*TheData$rho*fs.U**2*fs.area
TheData$SIDE <- TheData$CSide*1/2*TheData$rho*fs.U**2*fs.area
TheData$PITCH <- TheData$CPitch*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$ROLL <- TheData$CRoll*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$YAW <- TheData$CYaw*1/2*TheData$rho*fs.U**2*fs.area*fs.svl

# Some simple metrics
TheData$ClCd <- TheData$CLift/TheData$CDrag
TheData$glideangle <- atan2(TheData$CDrag,TheData$CLift)*180/pi
TheData$Umin <- sqrt((fs.m*g*cos(TheData$glideangle))/(1/2*TheData$rho*TheData$CLift*fs.area))
TheData$Uterm <- sqrt((fs.m*g)/(1/2*TheData$rho*TheData$CDrag*fs.area))
TheData$Upropelled <- sqrt((fs.m*g)/(1/2*TheData$rho*TheData$CLift*fs.area))






# now do some nice plots


# coefficients
fig5acoeffs <- ggplot(TheData, aes(aoa,CLift,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('lift coefficient')+geom_point(shape=15)+geom_smooth()
pdf(file="basicClvsaoa.pdf",width=3,height=2)
print(fig5acoeffs+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig5bcoeffs <- ggplot(TheData, aes(aoa,CDrag,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('drag coefficient')+geom_point(shape=15)+geom_smooth()
pdf(file="basicCdvsaoa.pdf",width=3,height=2)
print(fig5bcoeffs+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig5ccoeffs <- ggplot(TheData, aes(aoa,CPitch,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('pitch coefficient')+geom_point(shape=15)+geom_smooth()
pdf(file="basicCmvsaoa.pdf",width=3,height=2)
print(fig5ccoeffs+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig5dcoeffs <- ggplot(TheData, aes(CDrag,CLift,colour=basemodel))+xlab('drag coefficient')+ylab('lift coefficient')+opts(aspect.ratio=1)+geom_point(shape=15)
pdf(file="basicClvsCd.pdf",width=2,height=2)
print(fig5dcoeffs+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig5ecoeffs <- ggplot(TheData, aes(aoa,CLift/CDrag,colour=basemodel))+xlab('angle of attack, deg')+ylab('lift to drag ratio')+xlim(-15,90)+ylim(-1,5)+geom_point(shape=15)+geom_smooth()
pdf(file="basicLDratio.pdf",width=3,height=2)
print(fig5ecoeffs+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()






# Full scale forces
fig6aforces <- ggplot(TheData, aes(aoa,LIFT,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('full scale lift, N')+geom_point(shape=15)+geom_smooth()
pdf(file="basicfsLvsaoa.pdf",width=3,height=2)
print(fig6aforces+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig6bforces <- ggplot(TheData, aes(aoa,DRAG,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('full scale drag, N')+geom_point(shape=15)+geom_smooth()
pdf(file="basicfsDvsaoa.pdf",width=3,height=2)
print(fig6bforces+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig6cforces <- ggplot(TheData, aes(aoa,PITCH,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('full scale pitch, N m')+geom_point(shape=15)+geom_smooth()
pdf(file="basicfsMvsaoa.pdf",width=3,height=2)
print(fig6cforces+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig6dforces <- ggplot(TheData, aes(DRAG,LIFT,colour=basemodel))+xlab('full scale drag, N')+ylab('full scale lift, N')+opts(aspect.ratio=1)+geom_point(shape=15)
pdf(file="basicfsLvsD.pdf",width=2,height=2)
print(fig6dforces+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()






# model forces
fig7a <- ggplot(TheData, aes(aoa,lift,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('model lift, N')+geom_point(shape=15)+geom_smooth()
pdf(file="modelliftvsaoa.pdf",width=3,height=2)
print(fig7a+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig7b <- ggplot(TheData, aes(aoa,drag,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('model drag, N')+geom_point(shape=15)+geom_smooth()
pdf(file="modeldragvsaoa.pdf",width=3,height=2)
print(fig7b+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig7c <- ggplot(TheData, aes(aoa,pitch,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('model pitching moment, N m')+geom_point(shape=15)+geom_smooth()
pdf(file="modelpitchvsaoa.pdf",width=3,height=2)
print(fig7c+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig7d <- ggplot(TheData, aes(drag,lift,colour=basemodel))+xlab('model drag, N')+ylab('model lift, N')+opts(aspect.ratio=1)+geom_point(shape=15)
pdf(file="modelliftvsdrag.pdf",width=2,height=2)
print(fig7d+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig7e <- ggplot(TheData, aes(aoa,lift/drag,colour=basemodel))+xlab('angle of attack, deg')+ylab('lift to drag ratio')+xlim(-15,90)+ylim(-1,5)+geom_point(shape=15)#+geom_smooth()
pdf(file="modelLDratio.pdf",width=3,height=2)
print(fig7e+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()






# Metrics
fig8a <- ggplot(TheData, aes(aoa,ClCd,colour=basemodel))+xlim(-15,90)+ylim(0,4)+xlab('angle of attack, deg')+ylab('lift to drag ratio')+geom_point(shape=15)+geom_smooth()
pdf(file="liftdragratio.pdf",width=3,height=2)
print(fig8a+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig8b <- ggplot(TheData, aes(aoa,glideangle,colour=basemodel))+xlim(-15,90)+ylim(0,90)+xlab('angle of attack, deg')+ylab('glide angle, deg')+geom_point(shape=15)+geom_smooth()
pdf(file="glideangle.pdf",width=3,height=2)
print(fig8b+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig8c <- ggplot(TheData, aes(aoa,Umin,colour=basemodel))+xlim(-15,90)+ylim(0,30)+xlab('angle of attack, deg')+ylab('glide initiation speed, m/s')+geom_point(shape=15)+geom_smooth()
pdf(file="Umin.pdf",width=3,height=2)
print(fig8c+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig8d <- ggplot(TheData, aes(aoa,Uterm,colour=basemodel))+xlim(-15,90)+ylim(5,35)+xlab('angle of attack, deg')+ylab('terminal velocity, m/s')+geom_point(shape=15)+geom_smooth()
pdf(file="Uterm.pdf",width=3,height=2)
print(fig8d+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig8e <- ggplot(TheData, aes(aoa,Upropelled,colour=basemodel))+xlim(-15,90)+ylim(0,30)+xlab('angle of attack, deg')+ylab('self-propelled speed, m/s')+geom_point(shape=15)+geom_smooth()
pdf(file="Upropelled.pdf",width=3,height=2)
print(fig8e+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()





# find slopes
# sort the data
sortedData <- TheData[with(TheData,order(run,aoa)),]
mysloper <- function(df){with(df,data.frame(aoa=aoa[-1],dCMda=diff(CPitch)/(diff(aoa)*pi/180)))}
DCMDA <- ddply(sortedData,.(run),mysloper)
StabData <- merge(TheData,DCMDA)

fig8f <- ggplot(StabData, aes(aoa,dCMda,colour=basemodel))+xlim(-15,90)+xlab('angle of attack, deg')+ylab('pitching stability coefficient')+geom_point(shape=15)+geom_smooth()
pdf(file="pitchstab.pdf",width=3,height=2)
print(fig8f+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()




# Save excel spreadsheet 
write.table(StabData,"basicpitchaerodynamics.xls",sep="\t",na="",row.names=F)
