require(ggplot2)

# Load data and model data
D <- read.table('Microraptor gui static forces yaw.txt',header=TRUE)
M <- read.table('basic yaw stability models.txt',header=TRUE) # Load model data

# Select which to plot or do all
#D <- subset(D,aoa==0)
M <- subset(M,aoa==0)

# Strip out what we want and merge. 
TheData <- merge(D,M)
TheData <- droplevels(TheData) # Drop unused levels

# Compute some extra columns
# Nondimensional coefficients, referenced to sprawled planform
TheData$Re <- TheData$v*TheData$model.svl/TheData$nu
TheData$CLift <- TheData$lift/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CDrag <- TheData$drag/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CSide <- TheData$side/(1/2*TheData$rho*TheData$v**2*TheData$ref.area)
TheData$CPitch <- TheData$pitch/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CRoll <- TheData$roll/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)
TheData$CYaw <- TheData$yaw/(1/2*TheData$rho*TheData$v**2*TheData$ref.area*TheData$ref.svl)


# Scale up to full scale forces at 12 m/s (arbitrary)
fs.svl <- 0.306 # IVPP specimen
fs.area <- 0.211 # IVPP specimen
fs.m <- 1 # ??? 
g <- 9.81 # m/s^2
nu <- 15e-6 
fs.U <- 12 # iterate
fs.Re <- fs.U*fs.svl/nu
TheData$LIFT <- TheData$CLift*1/2*TheData$rho*fs.U**2*fs.area
TheData$DRAG <- TheData$CDrag*1/2*TheData$rho*fs.U**2*fs.area
TheData$SIDE <- TheData$CSide*1/2*TheData$rho*fs.U**2*fs.area
TheData$PITCH <- TheData$CPitch*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$ROLL <- TheData$CRoll*1/2*TheData$rho*fs.U**2*fs.area*fs.svl
TheData$YAW <- TheData$CYaw*1/2*TheData$rho*fs.U**2*fs.area*fs.svl


# Now do some plots

# coefficients
fig1 <- ggplot(TheData, aes(-hdg,-CSide,colour=basemodel))+xlim(-30,30)+xlab('yaw angle, deg')+ylab('side force coefficient')+geom_point(shape=15)+geom_smooth()
pdf(file="Csidevshdg.pdf",width=3,height=2)
print(fig1+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig2 <- ggplot(TheData, aes(-hdg,CYaw,colour=basemodel))+xlim(-30,30)+xlab('yaw angle, deg')+ylab('yaw moment coefficient')+geom_point(shape=15)+geom_smooth()
pdf(file="Cyawvshdg.pdf",width=3,height=2)
print(fig2+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()

fig3 <- ggplot(TheData, aes(-hdg,CRoll,colour=basemodel))+xlim(-30,30)+xlab('yaw angle, deg')+ylab('roll moment coefficient')+geom_point(shape=15)+geom_smooth()
pdf(file="Crollvshdg.pdf",width=3,height=2)
print(fig3+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()



# find slopes
# sort the data
sortedData <- TheData[with(TheData,order(run,hdg)),]
mysloper <- function(df){with(df,data.frame(hdg=hdg[-1],dCNdpsi=diff(CYaw)/(diff(-hdg)*pi/180)))}
DCNDPSI <- ddply(sortedData,.(run),mysloper)
StabData <- merge(TheData,DCNDPSI)

fig4 <- ggplot(StabData, aes(-hdg,dCNdpsi,colour=basemodel))+xlim(-30,30)+xlab('yaw angle, deg')+ylab('yaw stability coefficient')+geom_point(shape=15)+geom_smooth()
pdf(file="yawstab.pdf",width=3,height=2)
print(fig4+scale_colour_manual(values=c('Sprawled'="#E41A1C",'Tent'="#377EB8",'Biplane'="#4DAF4A",'Down'="#984EA3"))+theme_bw(base_size=8)+opts(legend.position="none"))
dev.off()



# Save excel spreadsheet 
write.table(StabData,"basicyawaerodynamics.xls",sep="\t",na="",row.names=F)

